@@ -9,7 +9,7 @@ import os_tests
 import json
 import difflib
 import time
-from os_tests.libs import rmt_ssh
+from tipset.libs import rmt_ssh
 from yaml import load, dump
 try:
     from yaml import CLoader as Loader, CDumper as Dumper
@@ -17,7 +17,7 @@ except ImportError:
     from yaml import Loader, Dumper
 
 def init_connection(test_instance, timeout=600):
-    if test_instance.params['remote_node'] != 'None':
+    if test_instance.params['remote_node'] is not None:
         test_instance.log.info("remote_node specified, all tests will be run in {}".format(test_instance.params['remote_node']))
         start_time = time.time()
         while True:
@@ -25,7 +25,7 @@ def init_connection(test_instance, timeout=600):
             if current_time - start_time > timeout:
                 test_instance.log.info("timeout to connect to remote")
                 break
-            test_instance.ssh_client = rmt_ssh.build_connection(rmt_node=test_instance.params['remote_node'],rmt_user=test_instance.params['remote_user'], rmt_password=test_instance.params['remote_password'], rmt_keyfile=test_instance.params['remote_keyfile'])
+            test_instance.ssh_client = rmt_ssh.build_connection(rmt_node=test_instance.params['remote_node'],rmt_user=test_instance.params['remote_user'], rmt_password=test_instance.params['remote_password'], rmt_keyfile=test_instance.params['remote_keyfile'], log=test_instance.log)
             if test_instance.ssh_client is not None:
                 break
             time.sleep(5)
@@ -35,23 +35,30 @@ def init_connection(test_instance, timeout=600):
     else:
         test_instance.ssh_client = None
 
-def init_case(test_instance):
-    """init case
-    Arguments:
-        test_instance {Test instance} -- unittest.TestCase instance
-    """
+def get_cfg():
     # Config file
     cfg_file = os.path.dirname(os_tests.__file__) + "/cfg/os-tests.yaml"
     # Result dir
     with open(cfg_file,'r') as fh:
        keys_data = load(fh, Loader=Loader)
+    return cfg_file, keys_data
+
+def init_case(test_instance):
+    """init case
+    Arguments:
+        test_instance {Test instance} -- unittest.TestCase instance
+    """
+    cfg_file, keys_data = get_cfg()
     test_instance.params = keys_data
     results_dir = keys_data['results_dir']
+    debug_dir = results_dir + "/debug"
     test_instance.log_dir = results_dir
     if not os.path.exists(results_dir):
         os.mkdir(results_dir)
+    if not os.path.exists(debug_dir):
+        os.mkdir(debug_dir)
     case_log = test_instance.id() + ".debug"
-    log_file = results_dir + '/' + case_log
+    log_file = debug_dir + '/' + case_log
     if os.path.exists(log_file):
         os.unlink(log_file)
     test_instance.log = logging.getLogger(__name__)
@@ -61,10 +68,14 @@ def init_case(test_instance):
     FORMAT = "%(levelname)s:%(message)s"
     logging.basicConfig(level=logging.DEBUG, format=FORMAT, filename=log_file)
     test_instance.log.info("Case id: {}".format(test_instance.id()))
-    test_instance.log.info(test_instance.params)
-    if test_instance.params['remote_node'] != 'None' or len(test_instance.params['remote_node']) >= 5:
+    for key in test_instance.params.keys():
+        if 'password' in key:
+            test_instance.log.info("key:{}, val:*******".format(key))
+        else:
+            test_instance.log.info("key:{}, val:{}".format(key, test_instance.params[key]))
+    if test_instance.params['remote_node'] is not None:
         test_instance.log.info("remote_node specified, all tests will be run in {}".format(test_instance.params['remote_node']))
-        test_instance.ssh_client = rmt_ssh.build_connection(rmt_node=test_instance.params['remote_node'],rmt_user=test_instance.params['remote_user'],rmt_password=test_instance.params['remote_password'],rmt_keyfile=test_instance.params['remote_keyfile'])
+        test_instance.ssh_client = rmt_ssh.build_connection(rmt_node=test_instance.params['remote_node'],rmt_user=test_instance.params['remote_user'],rmt_password=test_instance.params['remote_password'],rmt_keyfile=test_instance.params['remote_keyfile'], log=test_instance.log)
         if test_instance.ssh_client is None:
             test_instance.skipTest("Cannot make ssh connection to remote, please check")
     else:
@@ -155,7 +166,7 @@ def run_cmd(test_instance,
 
     try:
         if test_instance.ssh_client is not None:
-            status, output = rmt_ssh.remote_excute(test_instance.ssh_client, cmd, timeout, redirect_stdout=rmt_redirect_stdout, redirect_stderr=rmt_redirect_stderr,rmt_get_pty=rmt_get_pty)
+            status, output = rmt_ssh.remote_excute(test_instance.ssh_client, cmd, timeout, redirect_stdout=rmt_redirect_stdout, redirect_stderr=rmt_redirect_stderr,rmt_get_pty=rmt_get_pty, log=test_instance.log)
         else:
             ret = subprocess.run(cmd, shell=True, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, timeout=timeout, encoding='utf-8')
             status = ret.returncode
@@ -171,8 +182,8 @@ def run_cmd(test_instance,
         test_instance.log.info("Test via uname, if still fail, please make sure no hang or panic in sys")
         try:
             if test_instance.ssh_client is not None:
-                status, output = rmt_ssh.remote_excute(test_instance.ssh_client, 'uname -a', timeout)
-                status, output = rmt_ssh.remote_excute(test_instance.ssh_client, cmd, timeout, redirect_stdout=rmt_redirect_stdout, redirect_stderr=rmt_redirect_stderr, rmt_get_pty=rmt_get_pty)
+                status, output = rmt_ssh.remote_excute(test_instance.ssh_client, 'uname -a', timeout, log=test_instance.log)
+                status, output = rmt_ssh.remote_excute(test_instance.ssh_client, cmd, timeout, redirect_stdout=rmt_redirect_stdout, redirect_stderr=rmt_redirect_stderr, rmt_get_pty=rmt_get_pty, log=test_instance.log)
             else:
                 ret = subprocess.run('uname -a', shell=True, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, timeout=timeout, encoding='utf-8')
                 status = ret.returncode
@@ -239,22 +250,22 @@ def run_cmd(test_instance,
             if key_word in output:
                 cancel_yes = False
         if cancel_yes:
-            test_instance.skipTest("None of %s found, cancel case. %s" % (cancel_kw, msg))
+            test_instance.skipTest("'%s' not found, cancel case. msg:%s" % (cancel_kw, msg))
     if cancel_not_kw is not None:
         for key_word in cancel_not_kw.split(','):
             if key_word in output:
-                test_instance.skipTest("skip %s found, cancel case. %s" % (key_word, msg))
+                test_instance.skipTest("'%s' found, cancel case. msg:%s" % (key_word, msg))
     if cancel_ret is not None:
         cancel_yes = True
         for ret in cancel_ret.split(','):
             if int(ret) == int(status):
                 cancel_yes = False
         if cancel_yes:
-            test_instance.skipTest("expect ret code {} not match act ret {}, cancel case. {}".format(cancel_ret, status, msg))
+            test_instance.skipTest("expected ret code '{}' not match ret '{}', cancel case. msg:{}".format(cancel_ret, status, msg))
     if cancel_not_ret is not None:
         for ret in cancel_not_ret.split(','):
             if int(ret) == int(status):
-                test_instance.skipTest("skip ret code %s found act ret %s cancel case. %s" % (ret, status, msg))
+                test_instance.skipTest("skip ret code '%s' found act ret '%s' cancel case. msg:%s" % (ret, status, msg))
     if ret_status:
         return status
     return output
@@ -349,7 +360,7 @@ def is_aws(test_instance, action=None):
         aws: return True
         other: return False
     '''
-    output = run_cmd(test_instance, "cat /sys/devices/virtual/dmi/id/bios_*", expect_ret=0)
+    output = run_cmd(test_instance, "sudo cat /sys/devices/virtual/dmi/id/bios_*", expect_ret=0)
     if 'amazon' in output.lower():
         test_instance.log.info("AWS system.")
         return True
@@ -359,6 +370,26 @@ def is_aws(test_instance, action=None):
         test_instance.log.info("Not an aws system.")
     return False
 
+def is_ali(test_instance, action=None):
+    '''
+    Check whether system is a ali system.
+    Arguments:
+        test_instance {Test instance} -- unittest.TestCase instance
+        action {string} -- cancel case if it is not a ali system
+    Return:
+        aws: return True
+        other: return False
+    '''
+    output = run_cmd(test_instance, "sudo cat /sys/devices/virtual/dmi/id/product_*", expect_ret=0)
+    if 'alibaba' in output.lower():
+        test_instance.log.info("Ali system.")
+        return True
+    else:
+        if action == "cancel":
+            test_instance.skipTest("Cancel it in non ali system.")
+        test_instance.log.info("Not an ali system.")
+    return False
+
 def is_metal(test_instance, action=None):
     '''
     Check whether system is a baremetal system.
@@ -417,7 +448,8 @@ def is_cmd_exist(test_instance, cmd=None, is_install=True, cancel_case=False):
     if len(pkg_list) == 0:
         test_instance.skipTest("Unable to install {}".format(cmd))
         return False
-    run_cmd(test_instance, "sudo yum install -y %s" % pkg_list[0], expect_ret=0)
+    pkg_list.sort(reverse=True)
+    run_cmd(test_instance, "sudo yum install -y %s" % pkg_list[0], expect_ret=0, timeout=120)
     return True
 
 def is_pkg_installed(test_instance, pkg_name=None, is_install=True, cancel_case=False):
