@@ -11,9 +11,11 @@ class TestCloudInit(unittest.TestCase):
     def test_check_cloudinit_ds_identify_found(self):
         '''
         polarion_id:
-        bz#: 1746627
+        bz: 1746627
         check ds-identify run and ret found
         '''
+        cmd = 'rpm -q cloud-init'
+        utils_lib.run_cmd(self, cmd, cancel_not_kw='el8_0')
         cmd = 'sudo cat /run/cloud-init/cloud-init-generator.log'
         utils_lib.run_cmd(self,
                     cmd,
@@ -24,7 +26,7 @@ class TestCloudInit(unittest.TestCase):
     def test_check_cloudinit_log_imdsv2(self):
         '''
         polarion_id:
-        bz#: 1810704
+        bz: 1810704
         check cloud-init use imdsv2 in aws
         '''
         cmd = "sudo grep -Ri amazon /sys/devices/virtual/dmi/id/bios*"
@@ -44,7 +46,7 @@ class TestCloudInit(unittest.TestCase):
     def test_check_cloudinit_log_unexpected(self):
         '''
         polarion_id:
-        bz#: 1827207
+        bz: 1827207
         check no unexpected error log in cloudinit logs
         '''
         utils_lib.run_cmd(self,
@@ -63,7 +65,7 @@ class TestCloudInit(unittest.TestCase):
     def test_check_cloudinit_log_critical(self):
         '''
         polarion_id:
-        bz#: 1827207
+        bz: 1827207
         check no critical log in cloudinit logs
         '''
         utils_lib.run_cmd(self,
@@ -82,7 +84,7 @@ class TestCloudInit(unittest.TestCase):
     def test_check_cloudinit_log_warn(self):
         '''
         polarion_id:
-        bz#: 1821999
+        bz: 1821999
         check no warning log in cloudinit logs
         '''
         utils_lib.run_cmd(self,
@@ -101,7 +103,7 @@ class TestCloudInit(unittest.TestCase):
     def test_check_cloudinit_log_error(self):
         '''
         polarion_id:
-        bz#: 1821999
+        bz: 1821999
         check no error log in cloudinit logs
         '''
         utils_lib.run_cmd(self,
@@ -147,23 +149,34 @@ class TestCloudInit(unittest.TestCase):
     def test_check_output_isexist(self):
         '''
         polarion_id:
-        bz#: 1626117
+        bz: 1626117
         check whether /var/log/cloud-init-output.log exists
         '''
         utils_lib.run_cmd(self,
                     'uname -r',
                     cancel_not_kw='el7,el6',
                     msg='cancel it in RHEL7')
+        datasource = None
+        if utils_lib.is_ali(self):
+            datasource = 'Datasource DataSourceAliYun'
+        if utils_lib.is_aws(self):
+            datasource = 'Datasource DataSourceEc2'
         cmd = 'sudo cat /var/log/cloud-init-output.log'
-        utils_lib.run_cmd(self,
-                    cmd,
-                    expect_kw='Datasource DataSourceEc2Local',
-                    msg='check /var/log/cloud-init-output.log exists status')
+        if datasource is not None:    
+            utils_lib.run_cmd(self,
+                        cmd,
+                        expect_kw=datasource,
+                        msg='check /var/log/cloud-init-output.log exists status')
+        else:
+            utils_lib.run_cmd(self,
+                        cmd,
+                        expect_ret=0,
+                        msg='check /var/log/cloud-init-output.log exists status')
 
     def test_check_cloudinit_service_status(self):
         '''
         polarion_id:
-        bz#: 1829713
+        bz: 1829713
         The 4 cloud-init services status should be "active"
         '''
         service_list = ['cloud-init-local',
