@@ -17,8 +17,8 @@ class TestGeneralCheck(unittest.TestCase):
 
     def test_check_avclog_nfs(self):
         '''
+        bz: 1771856
         polarion_id: N/A
-        bz#: 1771856
         '''
         self.log.info("Check no permission denied at nfs server - bug1655493")
         cmd = 'sudo yum install -y nfs-utils'
@@ -47,8 +47,8 @@ class TestGeneralCheck(unittest.TestCase):
 
     def test_check_available_clocksource(self):
         '''
+        bz: 1726487
         polarion_id:
-        bz#: 1726487
         '''
         output = utils_lib.run_cmd(self, 'lscpu', expect_ret=0)
         if 'Xen' in output:
@@ -72,8 +72,8 @@ available_clocksource'
 
     def test_check_boot_time(self):
         '''
+        bz: 1776710
         polarion_id: RHEL7-93100
-        bz#: 1776710
         check the boot time.
         '''
         max_boot_time = self.params.get('max_boot_time')
@@ -103,23 +103,22 @@ available_clocksource'
 
     def test_check_dmesg_unable(self):
         '''
-        :avocado: tags=test_check_dmesg_unable,fast_check
+        bz: 1779454
         polarion_id:
-        bz#: 1779454
         '''
         utils_lib.check_log(self, 'unable', log_cmd='dmesg')
 
     def test_check_dmesg_calltrace(self):
         '''
+        bz: 1777179
         polarion_id: RHEL7-103851
-        bz#: 1777179
         '''
         utils_lib.run_cmd(self, 'dmesg', expect_ret=0, expect_not_kw='Call trace,Call Trace', msg="Check there is no call trace in dmesg")
 
     def test_check_dmesg_unknownsymbol(self):
         '''
+        bz: 1649215
         polarion_id:
-        bz#: 1649215
         '''
         utils_lib.run_cmd(self,
                     'dmesg',
@@ -127,6 +126,52 @@ available_clocksource'
                     expect_not_kw='Unknown symbol',
                     msg='Check there is no Unknown symbol in dmesg')
 
+    def test_check_dmidecode_outofspec(self):
+        '''
+        bz: 1858350
+        des: make sure there is no "OUT OF SPEC" in dmidecode output
+        '''
+        utils_lib.is_cmd_exist(self, cmd='dmidecode')
+        cmd = "sudo dmidecode --dump-bin {}/debug/dmidecode_debug.bin".format(self.log_dir)
+        utils_lib.run_cmd(self, cmd, msg='save dmidecode_debug.bin for debug purpose, please attach it if file bug')
+        utils_lib.run_cmd(self,
+                    'sudo dmidecode',
+                    expect_ret=0,
+                    expect_not_kw='OUT OF SPEC',
+                    msg='Check there is no "OUT OF SPEC" in dmidecode output')
+
+    def test_check_cpu_vulnerabilities(self):
+        '''
+        check if cpu has unexpected Vulnerable
+        '''
+
+        utils_lib.run_cmd(self, "rpm -qa|grep microcode", msg='Get microcode version')
+        utils_lib.run_cmd(self, "rpm -qa|grep linux-firmware",msg='get linux-firmware pkg version')
+        check_cmd = r"sudo grep . /sys/devices/system/cpu/vulnerabilities/* | \
+sed 's/:/^/' | column -t -s^"
+        utils_lib.run_cmd(self, check_cmd, expect_ret=0)
+
+        output = utils_lib.run_cmd(self, 'uname -r', expect_ret=0)
+        if utils_lib.is_metal(self):
+            self.log.info(
+                "Bare metal instance should not have any vulnerable (microload loaded).")
+            cmd = r"sudo grep . /sys/devices/system/cpu/vulnerabilities/* | \
+sed 's/:/^/' | column -t -s^"
+        elif 'el7' in output:
+            self.log.info(
+                "Skip spec_store_bypass,Retpoline and mds in RHEL7 vms")
+            check_cmd = r"sudo grep . /sys/devices/system/cpu/vulnerabilities/* | \
+grep -v spec_store_bypass|grep -v 'tsx_async_abort'|grep -v 'Vulnerable: Retpoline'|\
+grep -v mds| sed 's/:/^/' | column -t -s^"
+        else:
+            self.log.info(
+                "Skip spec_store_bypass and mds,itlb_multihit in vms")
+            check_cmd = r"sudo grep . /sys/devices/system/cpu/vulnerabilities/*|\
+grep -v spec_store_bypass|grep -v 'tsx_async_abort'|grep -v mds|grep -v \
+itlb_multihit|sed 's/:/^/' | column -t -s^"
+
+        utils_lib.run_cmd(self, check_cmd, expect_ret=0, expect_not_kw='Vulnerable')
+
     def test_iostat_x(self):
         '''
         case_name:
@@ -198,7 +243,7 @@ available_clocksource'
     def test_check_journal_calltrace(self):
         '''
         polarion_id:
-        bz#: 1801999, 1736818
+        bz: 1801999, 1736818
         '''
         # redirect journalctl output to a file as it is not get return
         # normally in RHEL7
@@ -211,7 +256,7 @@ available_clocksource'
     def test_check_journalctl_dumpedcore(self):
         '''
         polarion_id:
-        bz#: 1797973
+        bz: 1797973
         '''
         # redirect journalctl output to a file as it is not get return
         # normally in RHEL7
@@ -241,14 +286,14 @@ available_clocksource'
     def test_check_journalctl_invalid(self):
         '''
         polarion_id:
-        BZ#:1750417
+        bz:1750417
         '''
         utils_lib.check_log(self, 'invalid', skip_words="Invalid user,invalid user,test_check", rmt_redirect_stdout=True)
 
     def test_check_journalctl_service_unknown_lvalue(self):
         '''
         polarion_id:
-        BZ#:1871139
+        bz:1871139
         '''
         cmd = "systemctl list-unit-files |grep -v UNIT|grep -v listed|awk -F' ' '{print $1}'"
         all_services = utils_lib.run_cmd(self, cmd, msg='Get all systemd unit files').split('\n')
@@ -297,7 +342,7 @@ available_clocksource'
         '''
         utils_lib.is_cmd_exist(self, cmd='lshw')
         base_memory = utils_lib.get_memsize(self)
-        cmd = 'lshw -json'
+        cmd = 'sudo lshw -json'
         output = utils_lib.run_cmd(self, cmd, expect_ret=0)
         out = json.loads(output)['children'][0]["children"]
         for i in out:
@@ -347,6 +392,30 @@ available_clocksource'
         lsblk_out = utils_lib.run_cmd(self, lsblk_cmd, msg="Check nvme block device")
         self.assertEqual(lspci_out, lsblk_out, msg="No all nvme pci device nvme driver are loaded")
 
+    def test_check_meminfo_memfree(self):
+        '''
+        rhbz: 1880090
+        MemFree should less than MemTotal
+        Fail output:
+        # cat /sys/devices/system/node/node0/meminfo
+        Node 0 MemTotal:       30774804 kB
+        Node 0 MemFree:        31505560 kB
+        '''
+        out = utils_lib.run_cmd(self, 'sudo cat /sys/devices/system/node/node0/meminfo', expect_ret=0,
+                    msg="Check MemFree less than MemTotal")
+        memtotal = re.findall('[\d]+',re.findall('MemTotal:.*[\d]*',out)[0])[0]
+        memfree = re.findall('[\d]+',re.findall('MemFree:.*[\d]*',out)[0])[0]
+        memused = re.findall('[\d]+',re.findall('MemUsed:.*[\d]*',out)[0])[0]
+
+        if int(memfree) >= int(memtotal):
+            self.fail("memfree:{} >= memtotal:{}".format(memfree, memtotal))
+        else:
+            self.log.info("memfree:{} < memtotal:{}".format(memfree, memtotal))
+        if int(memused) >= int(memtotal):
+            self.fail("memused:{} >= memtotal:{}".format(memused, memtotal))
+        else:
+            self.log.info("memused:{} < memtotal:{}".format(memused, memtotal))
+
     def test_check_memleaks(self):
         '''
         polarion_id: RHEL-117648
@@ -371,12 +440,38 @@ available_clocksource'
         if len(output) > 0:
             self.fail('Memory leak found!')
 
+    def test_check_microcode_load(self):
+        '''
+        bz: 1607899
+        des: Don't attempt to perform early microcode update on virtualized guests
+        This case checks it from dmesg output.
+        '''
+        cpu_info = utils_lib.run_cmd(self,
+                    'lscpu',
+                    expect_ret=0,
+                    cancel_not_kw="aarch64",
+                    msg="Only run in x86 platform")
+        utils_lib.run_cmd(self, "rpm -qa|grep microcode",msg='get microcode pkg version')
+        utils_lib.run_cmd(self, "rpm -qa|grep linux-firmware",msg='get linux-firmware pkg version')
+        cmd = 'dmesg|grep microcode'
+        if utils_lib.is_metal(self):
+            utils_lib.run_cmd(self,
+                        cmd,
+                        expect_kw="microcode updated early",
+                        msg='microcode should load in bare metal')
+        else:
+            utils_lib.run_cmd(self,
+                        cmd,
+                        expect_not_kw='microcode updated early',
+                        msg='microcode should not load in VMs')
+
     def test_check_nouveau(self):
         '''
         polarion_id: N/A
-        BZ#: 1349927, 1645772
+        bz: 1349927, 1645772
         '''
         utils_lib.is_aws(self, action='cancel')
+        utils_lib.run_cmd(self, 'cat /etc/redhat-release', cancel_not_kw='CentOS', msg='skip this check on centos, rhbz1645772')
         self.log.info("nouveau is not required in ec2, make sure it is \
 in blacklist and not loaded bug1645772")
         utils_lib.run_cmd(self,
@@ -393,7 +488,7 @@ in blacklist and not loaded bug1645772")
     def test_check_nvme_io_timeout(self):
         '''
         polarion_id: N/A
-        bz#: 1859088
+        bz: 1859088
         '''
         utils_lib.is_aws(self, action='cancel')
         self.log.info("nvme_core.io_timeout=4294967295 is recommended in ec2, make sure it is \
@@ -407,6 +502,39 @@ in cmdline as bug1859088")
                     expect_kw="nvme_core.io_timeout=4294967295",
                     msg="Checking cmdline")
 
+    def test_check_release_name(self):
+        '''
+        polarion_id: RHEL7-103850
+        bz: 1852657
+        '''
+        check_cmd = "sudo cat /etc/redhat-release"
+        output = utils_lib.run_cmd(self,check_cmd, expect_ret=0, msg='check release name')
+        kernel_ver = utils_lib.run_cmd(self, 'uname -r', msg="Get kernel version")
+        name_map = {'el6':'Red Hat Enterprise Linux Server release 6',
+                    'el7':'Red Hat Enterprise Linux Server release 7',
+                    'el8':'Red Hat Enterprise Linux release 8',
+                    'el9':'Red Hat Enterprise Linux release 9',
+                    'el8_centos':'CentOS Stream release 8',
+                    'el9_centos':'CentOS Stream release 9'}
+        for key in name_map.keys():
+            if key in kernel_ver:
+                if 'CentOS' not in output:
+                    self.assertIn(
+                    name_map[key],
+                    output,
+                    msg="It should be like: {}.n but it is {}".format(name_map[key], output))
+                    if 'el6' not in kernel_ver and 'el7' not in kernel_ver:
+                        rhversion = re.findall('Red Hat Enterprise Linux release \d', output)[0]
+                        cmd = "sudo grep -R 'Red Hat Enterprise Linux' /boot/grub*|grep -v '{}'".format(rhversion)
+                        utils_lib.run_cmd(self, cmd, expect_not_ret=0, msg='make sure no other release name found')
+                else:
+                    centos_key = "{}_centos".format(key)
+                    self.assertIn(
+                    name_map[centos_key],
+                    output,
+                    msg="It should be like: {}.n but it is {}".format(name_map[centos_key], output))
+                break
+
     def test_check_proc_self_status(self):
         '''
         case_name:
@@ -439,6 +567,21 @@ in cmdline as bug1859088")
         '''
         utils_lib.run_cmd(self, 'cat /proc/self/status', expect_not_kw='unknown', msg='Check no unknown in "/proc/self/status"')
 
+    def test_check_product_id(self):
+        '''
+        bz: 1938930
+        issue: RHELPLAN-60817
+        check if product id matches /etc/redhat-release
+        '''
+        check_cmd = "sudo cat /etc/redhat-release"
+        output = utils_lib.run_cmd(self,check_cmd, expect_ret=0, cancel_not_kw='CentOS,Fedora', msg='check release name')
+        product_id = re.findall('\d.\d', output)[0]
+        self.log.info("Get product id: {}".format(product_id))
+        cmd = 'sudo rpm -qa|grep redhat-release'
+        utils_lib.run_cmd(self,cmd, cancel_ret='0', msg='get redhat-release-server version')
+        cmd = 'sudo rct cat-cert /etc/pki/product-default/*.pem'
+        utils_lib.run_cmd(self,cmd, expect_ret=0, expect_kw="Version: {}".format(product_id), msg='check product certificate')
+
     def test_check_service(self):
         '''
         case_name:
@@ -508,9 +651,9 @@ in cmdline as bug1859088")
 
     def test_check_tsc_deadline_timer(self):
         '''
-        polarion_id: RHEL7-111006
         des: check TSC deadline timer enabled in dmesg
-        BZ#: 1503160
+        bz: 1503160
+        polarion_id: RHEL7-111006
         '''
         utils_lib.run_cmd(self,
                     'lscpu',
@@ -519,7 +662,7 @@ in cmdline as bug1859088")
 
         cmd = "grep tsc_deadline_timer /proc/cpuinfo"
         utils_lib.run_cmd(self, cmd, cancel_ret='0', msg="check cpu flag has tsc_deadline_timer")
-        cmd = "dmesg|grep 'TSC deadline timer enabled'"
+        cmd = "dmesg|egrep 'TSC deadline timer enabled|TSC deadline timer available'"
         utils_lib.run_cmd(self, cmd, expect_ret=0)
 
         cmd = "sudo cat /sys/devices/system/clockevents/clockevent0/\
@@ -572,8 +715,8 @@ current_device"
 
     def test_check_virtwhat(self):
         '''
+        bz: 1782435
         polarion_id: RHEL7-103857
-        BZ#: 1782435
         test virt-what, not use systemd-detect-virt
         '''
         utils_lib.is_cmd_exist(self, cmd='virt-what')
@@ -604,6 +747,17 @@ current_device"
         else:
             self.skipTest("Unknow hypervisor")
 
+    def test_check_rpm_V_efi(self):
+        '''
+        bz: 1845052
+        '''
+        utils_lib.run_cmd(self,
+                    'sudo rpm -q efi-filesystem',
+                    cancel_not_kw="not installed", msg="check if efi-filesystem is installed")
+
+        cmd = "sudo rpm -V efi-filesystem"
+        utils_lib.run_cmd(self, cmd, expect_ret=0, msg="check rpm verify status")
+
     def test_collect_insights_result(self):
         '''
         case_name:
@@ -630,16 +784,25 @@ current_device"
         key_steps:
             1. #insights-client --register
             2. #insights-client --check-result
-            3. #insights-client --show-result
+            3. #insights-client --show-results
 
         expected_result:
             If run in dev compose, we simply assume there is no insights rule should be hit because no pkg update available in the latest build.
-            If run in old compose, please follow rule suggestion to check.
+            But if it is expected in dev compose, we can skip it in this case.
+            If run in GAed compose, please follow rule suggestion to check manually.
         '''
+        cmd="cat /etc/redhat-release"
+        utils_lib.run_cmd(self, cmd, cancel_not_kw='CentOS,Fedora', msg='Not run in centos')
         utils_lib.is_cmd_exist(self, cmd="insights-client")
+        utils_lib.run_cmd(self,
+                    'sudo lscpu',
+                    msg="get cpu information")
+        utils_lib.run_cmd(self,
+                    'sudo rpm -q insights-client',
+                    msg="get insights-client version")
         utils_lib.run_cmd(self,
                     'sudo insights-client --register',
-                    msg="try to register system")
+                    msg="try to register system", timeout=120)
         utils_lib.run_cmd(self,
                     'sudo insights-client --status',
                     cancel_kw="System is registered",
@@ -648,20 +811,24 @@ current_device"
                     'sudo insights-client --check-result',
                     expect_ret=0,
                     msg="checking system")
-        out = utils_lib.run_cmd(self,
+        result_out = utils_lib.run_cmd(self,
                     'sudo insights-client --show-result',
                     expect_ret=0,
                     msg="show insights result")
         #hit_list = json.loads(out)
-        if len(out) > 10:
-            out = utils_lib.run_cmd(self,
-                    'sudo insights-client --no-upload --keep-archive',
-                    expect_ret=0,
-                    msg="generate archive")
-            gz_file = re.findall('/var/.*tar.gz', out)[0]
-            file_name = gz_file.split('/')[-1]
-            utils_lib.run_cmd(self, 'sudo cp {} {}'.format(gz_file, self.log_dir))
-            self.fail("insights rule hit")
+        out = utils_lib.run_cmd(self,
+                'sudo insights-client --no-upload --keep-archive',
+                expect_ret=0, expect_kw="tar.gz",
+                msg="generate archive", timeout=180)
+        gz_file = re.findall('/var/.*tar.gz', out)[0]
+        file_name = gz_file.split('/')[-1]
+        utils_lib.run_cmd(self, 'sudo cp {} {}'.format(gz_file, self.log_dir))
+        try:
+            tmp_dict = json.loads(result_out)
+            if len(tmp_dict) > 0:
+                self.fail("{} insights rule hit".format(len(tmp_dict)))
+        except json.decoder.JSONDecodeError as exc:
+            self.log.error("insights rule hit or other unexpected error")
 
     def tearDown(self):
         self.log.info("{} test done".format(self.id()))
